@@ -25,9 +25,7 @@ REQUIRED_RE = re.compile(r"\'([\w]*)\' is a required property")
 
 
 class ValidationErrorAPIv2Adapter(base.APIv2Adapter):
-
     ADAPTER_OBJECT = objects.ValidationError
-
     MODIFICATIONS = {
         'fields': {
             "path": {},
@@ -43,10 +41,9 @@ class ValidationErrorAPIv2Adapter(base.APIv2Adapter):
     }
 
     @classmethod
-    def _render_object(cls, error, *args, **kwargs):
-
+    def render_object(cls, error, *args, **kwargs):
         # Do the usual rename
-        error_dict = super(ValidationErrorAPIv2Adapter, cls)._render_object(
+        error_dict = super(ValidationErrorAPIv2Adapter, cls).render_object(
             error, *args, **kwargs)
 
         # Currently JSON Schema doesn't add the path on for required items
@@ -54,10 +51,9 @@ class ValidationErrorAPIv2Adapter(base.APIv2Adapter):
             error_dict['path'].append(
                 REQUIRED_RE.match(error.message).group(1))
 
-        object = kwargs['failed_object']
-
+        obj = kwargs['failed_object']
         # Rename the keys in the path list
-        error_dict['path'] = cls._rename_path(object, error_dict['path'])
+        error_dict['path'] = cls._rename_path(obj, error_dict['path'])
 
         return error_dict
 
@@ -65,24 +61,25 @@ class ValidationErrorAPIv2Adapter(base.APIv2Adapter):
     def _rename_path(cls, object, path):
         new_path = list()
 
-        obj_adapter = cls.get_object_adapter(cls.ADAPTER_FORMAT, object)
+        obj_adapter = cls.get_object_adapter(object)
 
         for path_segment in path:
             new_path_segment, obj_adapter = cls._rename_path_segment(
-                obj_adapter, object, path_segment)
+                obj_adapter, object, path_segment
+            )
             new_path.append(new_path_segment)
 
         return new_path
 
     @classmethod
-    def _rename_path_segment(cls, obj_adapter, object, path_segment):
+    def _rename_path_segment(cls, obj_adapter, obj, path_segment):
 
         # Check if the object is a list - lists will just have an index as a
         # value, ands this can't be renamed
         if issubclass(obj_adapter.ADAPTER_OBJECT, objects.ListObjectMixin):
             obj_adapter = cls.get_object_adapter(
-                cls.ADAPTER_FORMAT,
-                obj_adapter.ADAPTER_OBJECT.LIST_ITEM_TYPE.obj_name())
+                obj_adapter.ADAPTER_OBJECT.LIST_ITEM_TYPE.obj_name()
+            )
             # Return the segment as is, and the next adapter (which is the
             # LIST_ITEM_TYPE)
             return path_segment, obj_adapter
@@ -91,37 +88,34 @@ class ValidationErrorAPIv2Adapter(base.APIv2Adapter):
                 'fields', {}).items():
 
             # Check if this field as actually a nested object
-            field = object.FIELDS.get(path_segment, {})
+            field = obj.FIELDS.get(path_segment, {})
             if isinstance(field, dict) and field.get('relation'):
-                obj_cls = object.FIELDS.get(path_segment).get('relation_cls')
-                obj_adapter = cls.get_object_adapter(
-                    cls.ADAPTER_FORMAT,
-                    obj_cls)
+                obj_cls = obj.FIELDS.get(path_segment).get('relation_cls')
+                obj_adapter = cls.get_object_adapter(obj_cls)
 
-                object = objects.DesignateObject.obj_cls_from_name(obj_cls)()
+                new_obj = objects.DesignateObject.obj_cls_from_name(obj_cls)()
                 # Recurse down into this object
                 path_segment, obj_adapter = cls._rename_path_segment(
-                    obj_adapter, object, path_segment)
+                    obj_adapter, new_obj, path_segment
+                )
 
                 # No need to continue the loop
                 break
             elif hasattr(field, 'objname'):
                 obj_cls = field.objname
-                obj_adapter = cls.get_object_adapter(
-                    cls.ADAPTER_FORMAT, obj_cls)
+                obj_adapter = cls.get_object_adapter(obj_cls)
 
-                object = objects.DesignateObject.obj_cls_from_name(obj_cls)()  # noqa
+                new_obj = objects.DesignateObject.obj_cls_from_name(obj_cls)()
                 # Recurse down into this object
                 path_segment, obj_adapter = cls._rename_path_segment(
-                    obj_adapter, object, path_segment)
+                    obj_adapter, new_obj, path_segment)
 
                 # No need to continue the loop
                 break
 
-            if not isinstance(
-                value.get(
-                    'rename', NotSpecifiedSential()), NotSpecifiedSential)\
-                    and path_segment == value.get('rename'):
+            if (not isinstance(value.get('rename', NotSpecifiedSential()),
+                               NotSpecifiedSential) and
+                    path_segment == value.get('rename')):
                 # Just do the rename
                 path_segment = key
 
@@ -129,9 +123,7 @@ class ValidationErrorAPIv2Adapter(base.APIv2Adapter):
 
 
 class ValidationErrorListAPIv2Adapter(base.APIv2Adapter):
-
     ADAPTER_OBJECT = objects.ValidationErrorList
-
     MODIFICATIONS = {
         'options': {
             'links': False,
