@@ -17,7 +17,6 @@
 #    under the License.
 
 from oslo_db import exception as oslo_db_exception
-from oslo_db.sqlalchemy.migration_cli import manager
 from oslo_db.sqlalchemy import utils
 from oslo_log import log
 import sqlalchemy
@@ -41,15 +40,6 @@ RRSET_FILTERING_INDEX = {
 }
 
 
-def get_migration_manager(repo_path, url, init_version=None):
-    migration_config = {
-        'migration_repo_path': repo_path,
-        'db_url': url,
-        'init_version': init_version,
-    }
-    return manager.MigrationManager(migration_config)
-
-
 # copy from olso/db/sqlalchemy/utils.py
 def paginate_query(query, table, limit, sort_keys, marker=None,
                    sort_dir=None, sort_dirs=None):
@@ -109,8 +99,7 @@ def sort_query(query, table, sort_keys, sort_dir=None, sort_dirs=None):
 
     assert(len(sort_dirs) == len(sort_keys))
 
-    for current_sort_key, current_sort_dir in \
-            zip(sort_keys, sort_dirs):
+    for current_sort_key, current_sort_dir in zip(sort_keys, sort_dirs):
         try:
             sort_dir_func = {
                 'asc': sqlalchemy.asc,
